pub struct MysqlLikeConnection<DB: MysqlLikeBackend> { /* private fields */ }mariadb_backend or mysql_backend) and (crate features mariadb or mysql) only.Expand description
A connection to a MySQL database. Connection URLs should be in the form
mysql://[user[:password]@]host/database_name[?unix_socket=socket-path&ssl_mode=SSL_MODE*&ssl_ca=/etc/ssl/certs/ca-certificates.crt&ssl_cert=/etc/ssl/certs/client-cert.crt&ssl_key=/etc/ssl/certs/client-key.crt]
hostcan be an IP address or a hostname. If it is set tolocalhost, a connection will be attempted through the socket at/tmp/mysql.sock. If you want to connect to a local server via TCP (e.g. docker containers), use0.0.0.0or127.0.0.1instead.unix_socketexpects the path to the unix socketssl_caaccepts a path to the system’s certificate rootsssl_certaccepts a path to the client’s certificate filessl_keyaccepts a path to the client’s private key filessl_modeexpects a value defined for MySQL client command option--ssl-modeSee https://dev.mysql.com/doc/refman/5.7/en/connection-options.html#option_general_ssl-mode
Supported loading model implementations
As MysqlConnection only supports a single loading mode implementation
it is not required to explicitly specify a loading mode
when calling RunQueryDsl::load_iter() or LoadConnection::load
DefaultLoadingMode
MysqlConnection only supports a single loading mode, which loads
values row by row from the result set.
use diesel::connection::DefaultLoadingMode;
{
// scope to restrict the lifetime of the iterator
let iter1 = users::table.load_iter::<(i32, String), DefaultLoadingMode>(connection)?;
for r in iter1 {
let (id, name) = r?;
println!("Id: {} Name: {}", id, name);
}
}
// works without specifying the loading mode
let iter2 = users::table.load_iter::<(i32, String), _>(connection)?;
for r in iter2 {
let (id, name) = r?;
println!("Id: {} Name: {}", id, name);
}This mode does not support creating multiple iterators using the same connection.
use diesel::connection::DefaultLoadingMode;
let iter1 = users::table.load_iter::<(i32, String), DefaultLoadingMode>(connection)?;
let iter2 = users::table.load_iter::<(i32, String), DefaultLoadingMode>(connection)?;
for r in iter1 {
let (id, name) = r?;
println!("Id: {} Name: {}", id, name);
}
for r in iter2 {
let (id, name) = r?;
println!("Id: {} Name: {}", id, name);
}Trait Implementations
Sourceimpl<DB: MysqlLikeBackend> Connection for MysqlLikeConnection<DB>
impl<DB: MysqlLikeBackend> Connection for MysqlLikeConnection<DB>
Sourcefn establish(database_url: &str) -> ConnectionResult<Self>
fn establish(database_url: &str) -> ConnectionResult<Self>
Establishes a new connection to the MySQL database
database_url may be enhanced by GET parameters
mysql://[user[:password]@]host[:port]/database_name[?unix_socket=socket-path&ssl_mode=SSL_MODE*&ssl_ca=/etc/ssl/certs/ca-certificates.crt&ssl_cert=/etc/ssl/certs/client-cert.crt&ssl_key=/etc/ssl/certs/client-key.crt&local_infile=true]
hostcan be an IP address or a hostname. If it is set tolocalhost, a connection will be attempted through the socket at/tmp/mysql.sock. If you want to connect to a local server via TCP (e.g. docker containers), use0.0.0.0or127.0.0.1instead.unix_socketexpects the path to the unix socketssl_caaccepts a path to the system’s certificate rootsssl_certaccepts a path to the client’s certificate filessl_keyaccepts a path to the client’s private key filessl_modeexpects a value defined for MySQL client command option--ssl-modeSee https://dev.mysql.com/doc/refman/5.7/en/connection-options.html#option_general_ssl-modelocal_infileexpects a boolean to enable or disable LOAD DATA LOCAL
Sourcetype TransactionManager = AnsiTransactionManager
type TransactionManager = AnsiTransactionManager
Sourcefn execute_returning_count<T>(&mut self, source: &T) -> QueryResult<usize>
fn execute_returning_count<T>(&mut self, source: &T) -> QueryResult<usize>
Sourcefn transaction_state(&mut self) -> &mut AnsiTransactionManager
fn transaction_state(&mut self) -> &mut AnsiTransactionManager
Sourcefn instrumentation(&mut self) -> &mut dyn Instrumentation
fn instrumentation(&mut self) -> &mut dyn Instrumentation
Sourcefn set_instrumentation(&mut self, instrumentation: impl Instrumentation)
fn set_instrumentation(&mut self, instrumentation: impl Instrumentation)
Instrumentation implementation for this connectionSourcefn set_prepared_statement_cache_size(&mut self, size: CacheSize)
fn set_prepared_statement_cache_size(&mut self, size: CacheSize)
CacheSize for this connectionSourcefn transaction<T, E, F>(&mut self, f: F) -> Result<T, E>
fn transaction<T, E, F>(&mut self, f: F) -> Result<T, E>
Sourcefn begin_test_transaction(&mut self) -> QueryResult<()>
fn begin_test_transaction(&mut self) -> QueryResult<()>
impl<DB: MysqlLikeBackend> ConnectionSealed for MysqlLikeConnection<DB>
Sourceimpl<DB: MysqlLikeBackend> LoadConnection for MysqlLikeConnection<DB>
impl<DB: MysqlLikeBackend> LoadConnection for MysqlLikeConnection<DB>
Sourcetype Cursor<'conn, 'query> = StatementIterator<'conn, DB>
type Cursor<'conn, 'query> = StatementIterator<'conn, DB>
LoadConnection::load Read moreSourcetype Row<'conn, 'query> = MysqlRow<DB>
type Row<'conn, 'query> = MysqlRow<DB>
Iterator::Item for the iterator implementation
of LoadConnection::CursorSourcefn load<'conn, 'query, T>(
&'conn mut self,
source: T,
) -> QueryResult<Self::Cursor<'conn, 'query>>where
T: Query + QueryFragment<Self::Backend> + QueryId + 'query,
Self::Backend: QueryMetadata<T::SqlType>,
fn load<'conn, 'query, T>(
&'conn mut self,
source: T,
) -> QueryResult<Self::Cursor<'conn, 'query>>where
T: Query + QueryFragment<Self::Backend> + QueryId + 'query,
Self::Backend: QueryMetadata<T::SqlType>,
Sourceimpl<DB: MysqlLikeBackend> MultiConnectionHelper for MysqlLikeConnection<DB>
impl<DB: MysqlLikeBackend> MultiConnectionHelper for MysqlLikeConnection<DB>
Sourcefn to_any<'a>(
lookup: &mut <Self::Backend as TypeMetadata>::MetadataLookup,
) -> &mut (dyn Any + 'a)
fn to_any<'a>( lookup: &mut <Self::Backend as TypeMetadata>::MetadataLookup, ) -> &mut (dyn Any + 'a)
i-implement-a-third-party-backend-and-opt-into-breaking-changes only.Sourcefn from_any(
lookup: &mut dyn Any,
) -> Option<&mut <Self::Backend as TypeMetadata>::MetadataLookup>
fn from_any( lookup: &mut dyn Any, ) -> Option<&mut <Self::Backend as TypeMetadata>::MetadataLookup>
i-implement-a-third-party-backend-and-opt-into-breaking-changes only.Sourceimpl<DB: MysqlLikeBackend> R2D2Connection for MysqlLikeConnection<DB>
Available on crate feature r2d2 only.
impl<DB: MysqlLikeBackend> R2D2Connection for MysqlLikeConnection<DB>
r2d2 only.impl<DB: MysqlLikeBackend> Send for MysqlLikeConnection<DB>
Sourceimpl<DB: MysqlLikeBackend> SimpleConnection for MysqlLikeConnection<DB>
impl<DB: MysqlLikeBackend> SimpleConnection for MysqlLikeConnection<DB>
Sourcefn batch_execute(&mut self, query: &str) -> QueryResult<()>
fn batch_execute(&mut self, query: &str) -> QueryResult<()>